import math
from .Shape import Shape

class Circle(Shape):
    
    def __init__(self, color = 'black', radius = 1):
    
        self.radius = radius
        Shape.__init__(self, color)
    
    def get_area(self):
        return  math.pi * (self.radius  ** 2)
    
    def get_perimeter(self):
        return 2 * math.pi * self.radius


import unittest

from Circle import Circle

class TestCircleClass(unittest.TestCase):
    def setUp(self):
        self.circle = Circle('red', 5)

    def test_initialization(self): 
        self.assertEqual(self.circle.color, 'red', 'incorrect mean')
        self.assertEqual(round(self.circle.get_area(),2), 78.54, 'incorrect mean')

    
if __name__ == '__main__':
    unittest.main()


# TODO: Fill out this file with information about your package

# HINT: Go back to the object-oriented programming lesson "Putting Code on PyPi" and "Exercise: Upload to PyPi"

# HINT: Here is an example of a setup.py file
# https://packaging.python.org/tutorials/packaging-projects/

from setuptools import setup

setup(name='tomshapes',
      version='1.0.1',
      description='Python Shapes distro',
      author='Tom Mathew',
      author_email='something@nothing.com',
      url='https://nothing.com/',
      packages=['tomshapes'],
     )
